@@ -1,8 +1,10 @@
 context("maxLikelihood.Guilds")
 
 test_that("maxLikelihood.Guilds: use", {
+#  skip_on_cran() # takes too long
+ # testthat::skip("takes too long")
   set.seed(42)
-  J <- 100
+  J <- 1000
 
   theta <- 1000
   alpha_x <- 0.1
@@ -10,19 +12,19 @@ test_that("maxLikelihood.Guilds: use", {
   simul_data <- generate.Guilds(theta, alpha_x, alpha_x, J)
 
   #initial parameters for the D0 model c(theta,alpha)
-  testthat::expect_output(
+#  testthat::expect_output(
   LL <- GUILDS::maxLikelihood.Guilds(init_vals = c(theta, alpha_x),
                              model = "D0",
                              sadx  = simul_data$guildX,
-                             sady  = simul_data$guildY, verbose = TRUE)
-  )
+                             sady  = simul_data$guildY, verbose = FALSE)
+ # )
   testthat::expect_equal(
     alpha_x,
     LL$par[2],
     tolerance = 0.05, scale = 1
   )
 
-  J <- 100
+  J <- 1000
 
   theta <- 100
   alpha_x <- 0.1
@@ -30,13 +32,13 @@ test_that("maxLikelihood.Guilds: use", {
 
   simul_data <- generate.Guilds(theta, alpha_x, alpha_y, J)
 
-  testthat::expect_output(
+  #testthat::expect_output(
   #initial parameters for the D1 model c(theta, alpha_x, alpha_y)
   LL <- maxLikelihood.Guilds( init_vals = c(theta, alpha_x, alpha_y),
                               model = "D1",
                               sadx  = simul_data$guildX,
-                              sady  = simul_data$guildY, verbose = TRUE)
-  )
+                              sady  = simul_data$guildY, verbose = FALSE)
+  #)
 
   testthat::expect_equal(
     alpha_x,
